/**
 * blog controller
 */

import { Strapi, factories } from "@strapi/strapi";
import { sanitize, validate } from "@strapi/utils";

export default factories.createCoreController(
  "api::blog.blog",
  ({ strapi }: { strapi: Strapi }) => {
    return {
      async getDetailMe(ctx) {
        try {
          const { slug } = ctx.params;
          if (!slug) {
            return ctx.badRequest({ error: "Missing slug" });
          }

          const sanitizedQueryParams = await this?.sanitizeQuery(ctx);

          const entry = await strapi.db.query("api::blog.blog").findOne({
            ...sanitizedQueryParams,
            where: { slug },
            populate: {
              creator: true,
              comments: {
                populate: ["user"],
              },
              thumbnail: true,
            },
          });

          if (!entry) {
            return ctx.notFound();
          }

          const sanitizedEntry = await this?.sanitizeOutput(entry, ctx);
          return this?.transformResponse(sanitizedEntry);
        } catch (error) {
          return ctx.badRequest({ error: error.message });
        }
      },
    };
  }
);
